@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20260130';
+our $VERSION = '0.20260227';
 
-# Table last modified: 2026-01-30
+# Table last modified: 2026-02-27
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -63,7 +63,7 @@ our %ZIP_TABLE = (
     '057' => '(?:85(?:11|58))',
     '058' => '(?:(?:0292|8501))',
     '059' => '(?:(?:1(?:39[2-6]|59[2-6]|69[23]|292)|0(?:59[2568]|99[3578]|49[236])|2(?:[14]92|598)|8[67]01|3195))',
-    '060' => '(?:8(?:5(?:[38]\d|4[1-9]|[12][0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|6(?:1\d|8[6-8]|7[016-8]|0[1-9]|5[124-68]|6[16-8]|4[0-47-9]|2[13-57-9]|3[0-24-9])|7(?:11|9[5-7]|7[146]|6[67]|0[35-7]|2[15])|406))',
+    '060' => '(?:8(?:5(?:[38]\d|4[1-9]|[12][0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|6(?:1\d|8[6-8]|7[016-8]|0[1-9]|5[124-68]|6[16-8]|2[13-57-9]|4[0-46-9]|3[0-24-9])|7(?:11|9[5-7]|7[146]|6[67]|0[35-7]|2[15])|406))',
     '061' => '(?:(?:1(?:39[2-6]|49[236-8]|19[256])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292|8501))',
     '062' => '(?:8(?:6(?:1[278]|0[1-357-9]|3[0135]|2[24]|4[12]|6[68])|5(?:01|20|55|7[025]|3[029]|1[01467])))',
     '063' => '(?:8(?:5(?:22|0[17]|5[58]|[18][05])|6(?:0[1-36-8]|1[12]|4[15])))',
@@ -107,11 +107,11 @@ our %ZIP_TABLE = (
     '101' => '(?:8(?:6(?:8[28]|0[356]|5[146]|6[57]|2[1246-9]|3[01367]|7[026]|4[235-8]|1[01679])|4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|2[12459]|5[0169])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:5[013589]|8[38]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:1[0-357-9]|2[02-58]|8[124-8]|0[239]|5[0-25]|3[0-289]|7[0-25-8]|9[0-5]|4[0-24]|6[016])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|5[156]|7[17-9]|1[0-47-9]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|4[0158]|0[125-7]|1[0-2479]|2[0146]|8[489]|3[037])|2(?:5[015]|3[0-24-68]|6[045]|8[28]|7[2-57]|2[1-68]|[01][15]|4[016])|3(?:4[13]|7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])|811))',
     '103' => '(?:8(?:2(?:5[0-2569]|3[0-689]|7[036-8]|0[1-68]|8[2457]|1[0-248]|6[0156]|2[124589]|4[013578])|4(?:7[0-3]|0[1-57]|4[38]|3[0-589]|1[0-79]|2[24-7]|6[0-24-6]|8[02457-9]|5[016])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|2[0-25]|0[1-356]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
-    '104' => '(?:(?:8(?:3(?:5[0-356]|1[023579]|6[356]|7[07-9]|8[013689]|3[02358]|2[1-58]|4[0-5]|0[12467])|1(?:50|65|1[04-68]|3[0-259]|7[014589]|8[389]|2[4589]|4[578]|0[124589])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|4[0349]|2[0-469]|6[078])|5(?:33|77|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:[03]8|40|71|5[124578]|1[28]|6[236]|8[0-59])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
+    '104' => '(?:(?:8(?:3(?:5[0-356]|1[023579]|6[356]|7[07-9]|8[013689]|2[1-68]|3[02358]|4[0-5]|0[12467])|1(?:50|65|1[04-68]|3[0-259]|7[014589]|8[389]|2[4589]|4[578]|0[124589])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|4[0349]|2[0-469]|6[078])|5(?:33|77|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:[03]8|40|71|5[124578]|1[28]|6[236]|8[0-59])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
     '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|0[1-47-9]|[46][014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|4[0-7]|3[01358]|0[1-9]|2[235])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[05-7]|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:4(?:20|5[06]|7[127]|0[1-4]|1[126-9]|3[14]|8[24]|4[08]|6[038])|5(?:32|81|0[23578]|7[02]|1[146]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:20|4[0289]|7[013]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
-    '108' => '(?:(?:8(?:5(?:2[0-35]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|4[035]|8[0-3568])|3(?:2[25689]|3[134]|1[0356]|7[2359]|8[013-689]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|7[056]|4[0-38]|1[0-267]|0[1-36-9]|3[0-4]|5[05]|2[02-5])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|2[2358]|3[1-3689]|0[267]|1[125-8]|4[0-28])|0(?:[258]0|71|[01][15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
+    '108' => '(?:(?:8(?:5(?:2[0-35]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|4[035]|8[0-3568])|3(?:2[25689]|3[134]|1[0356]|7[2359]|8[013-689]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|7[056]|4[0-38]|1[0-267]|0[1-36-9]|3[0-4]|5[05]|2[02-5])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:5[04]|2[2358]|3[1-3689]|0[267]|1[125-8]|4[0-28])|0(?:[258]0|[07]1|1[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|3[0158]|4[124-6]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|0[6-8]|1[2-6]|2[235]|3[36])|408|807))',
     '111' => '(?:8(?:6(?:3[01379]|1[0-258]|2[0-358]|7[6-8]|8[1368]|0[2568]|6[16]|5[05]|4[0248])|5(?:43|1[0-2568]|8[058]|5[1568]|7[57]|6[0167]|0[126-8]|2[125]|3[0-59])|7(?:[56]5|21|98|0[178]|1[01])|081))',
@@ -125,7 +125,7 @@ our %ZIP_TABLE = (
     '123' => '(?:85(?:[58]8|40|1[124]|0[135-9]))',
     '124' => '(?:85(?:60|77|2[04]|3[03589]|0[1-39]|8[58]|5[05]|1[01]))',
     '125' => '(?:8(?:5(?:0[3-8]|8[58]|1[1-47]|2[026])|601))',
-    '130' => '(?:8(?:5(?:8[03-58]|2[0-258]|7[057]|3[013-589]|5[3-8]|4[3568]|6[135-7]|0[13-9]|1[0-8])|6(?:71|86|4[02]|3[367]|5[05]|2[58]|6[068]|1[125]|0[1-689])|7(?:[12]0|0[16])))',
+    '130' => '(?:8(?:5(?:8[03-58]|2[0-258]|7[057]|3[013-589]|5[3-8]|4[3568]|6[135-7]|0[13-9]|1[0-8])|6(?:71|4[02]|3[367]|5[05]|2[58]|6[068]|8[68]|1[125]|0[1-689])|7(?:[12]0|0[16])))',
     '131' => '(?:8(?:5(?:65|1[0-389]|3[03]|2[0467]|5[058]|8[458]|0[1357-9])|139|634|711))',
     '132' => '(?:8(?:5(?:[18]5|5[015]|3[03]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[058]|5[238])|70[46]))',
@@ -195,7 +195,7 @@ our %ZIP_TABLE = (
     '206' => '(?:8(?:5(?:30|77|4[03]|2[025]|0[25]|8[568]|1[0-25]|6[167]|5[15])|6(?:[01]1|[68]6)))',
     '207' => '(?:85(?:[18]5|01))',
     '208' => '(?:85(?:[58]5|0[1-3]))',
-    '210' => '(?:(?:8(?:5(?:0[246]|6[0259]|2[13]|3[178]|4[013-578]|7[067]|1[12]|8[56]|5[127-9])|6(?:66|0[24]|8[016])|79[3-8])|9(?:5(?:11|26|55|67|82|3[03]|0[17])|650)))',
+    '210' => '(?:(?:8(?:5(?:0[246]|6[0259]|2[13]|3[178]|4[013-578]|7[067]|1[12]|8[56]|5[127-9])|6(?:6[06]|0[24]|8[016])|79[3-8])|9(?:5(?:11|26|55|67|82|3[03]|0[17])|650)))',
     '211' => '(?:8(?:5(?:22|66|3[03]|7[07]|8[58]|5[05]|1[01]|0[125])|6(?:66|75|1[19]|0[12])))',
     '212' => '(?:8(?:5(?:25|30|6[0467]|5[147]|7[0267]|8[1-5]|0[2589]|1[01])|60[2-4]))',
     '213' => '(?:85(?:66|0[2357]|8[07-9]|2[0-25]|1[125-7]|3[35]|7[0367]|5[0138]))',
@@ -204,7 +204,7 @@ our %ZIP_TABLE = (
     '216' => '(?:8(?:5(?:[56]6|01|22|70|1[0-249])|631))',
     '220' => '(?:8(?:5(?:77|1[015]|3[0689]|[24][0-3]|6[0-7]|5[89]|8[0568]|0[127-9])|6(?:53|60|0[149]|1[1-6]|8[046]|2[035])|7(?:11|39|65|2[02]|5[05])|080|173|401))',
     '221' => '(?:8(?:5(?:[46]0|37|88|2[0239]|5[08]|1[017])|7(?:41|65|1[28]|0[1-35])|6(?:[68]6|11|23)))',
-    '222' => '(?:8(?:5(?:5[028]|1[015]|3[03]|8[056]|6[1-6]|7[57]|0[157-9]|2[035])|6[25]2))',
+    '222' => '(?:8(?:5(?:5[028]|1[015]|3[03]|8[056]|6[1-6]|2[0235]|7[57]|0[157-9])|6[25]2))',
     '223' => '(?:85(?:7[027]|[58][058]|1[0-25]|2[0-35-7]|6[067]|4[0-2]|0[125-8]|3[039]))',
     '224' => '(?:8(?:5(?:39|40|78|8[058]|1[05]|0[1-7]|5[01]|2[024])|6(?:01|8[68])))',
     '225' => '(?:85(?:[56]0|13|85|2[25]|0[1-38]|3[059]))',
@@ -239,14 +239,14 @@ our %ZIP_TABLE = (
     '257' => '(?:85(?:[23]3|11|55|66|77|8[458]|0[12]))',
     '258' => '(?:(?:85(?:11|77|85|3[38]|0[16])|0195))',
     '259' => '(?:(?:0(?:1(?:9[2-467]|8[01])|39[2356])|1(?:1(?:8[5-8]|9[236-8])|[23]92)))',
-    '260' => '(?:8(?:6(?:0[13467]|1[0-389]|8[1258]|5[46]|4[2578]|6[0-35-8]|7[0-357]|2[0-24-7]|3[135-7])|5(?:40|7[0257]|5[1257-9]|8[0568]|1[0-35-8]|0[1-35-9]|3[4-68]|6[0-467]|2[13478])|7(?:33|1[02357]|0[137]|2[02])))',
+    '260' => '(?:8(?:6(?:0[13467]|8[1258]|1[0-489]|5[46]|4[2578]|6[0-35-8]|7[0-357]|2[0-24-7]|3[135-7])|5(?:40|7[0257]|5[1257-9]|8[0568]|1[0-35-8]|0[1-35-9]|3[4-68]|6[0-467]|2[13478])|7(?:33|1[02357]|0[137]|2[02])))',
     '261' => '(?:8(?:5(?:1[0-35]|6[0168]|3[0359]|8[0-25-8]|7[57]|5[0248]|0[1-478]|4[145]|2[0-28])|6(?:86|0[1-39])|733))',
     '262' => '(?:8(?:5(?:0[26]|1[0-2])|733))',
     '263' => '(?:8(?:5(?:[12]2|33|77|6[06]|8[58]|5[05]|0[56])|733))',
     '264' => '(?:8(?:5(?:[135]0|8[25]|0[15])|6(?:04|46)|733))',
     '265' => '(?:8501)',
     '266' => '(?:8(?:550|733))',
-    '270' => '(?:(?:1(?:3(?:8[0-3579]|9[23568])|19[2468]|49[2356]|69[3-5]|592)|2(?:2(?:9[2-8]|8[068])|39[23])|01(?:89|9[24-8])|85(?:[0-2]1|55)))',
+    '270' => '(?:(?:1(?:3(?:8[0-3579]|9[23568])|19[2468]|49[2356]|69[3-5]|592)|2(?:2(?:9[2-8]|8[068])|39[23])|01(?:8[09]|9[2-8])|85(?:[0-2]1|55)))',
     '271' => '(?:8(?:5(?:01|22|3[03]|[18][058]|5[157]|6[02-4])|6(?:66|72|2[05])))',
     '272' => '(?:(?:85(?:01|73|4[03]|5[058]|2[02]|8[0158]|1[0-468]|6[01]|3[038])|01(?:88|9[35])))',
     '273' => '(?:(?:8(?:5(?:3[03]|2[0-3]|8[458]|1[0-25]|7[048]|6[067]|4[023]|5[01568]|0[1-68])|6(?:01|10|27)|7(?:10|33))|019[235-7]))',
@@ -293,7 +293,7 @@ our %ZIP_TABLE = (
     '317' => '(?:8(?:5(?:[58]5|11)|60[12]))',
     '318' => '(?:85(?:11|0[15]))',
     '319' => '(?:(?:1(?:1(?:8[248]|9[24-7])|29[235]|59[23]|393)|0(?:39[3-57]|29[245]|19[28])|2[16]92|3595))',
-    '320' => '(?:8(?:5(?:5[015]|3[0-38]|0[1-35-8]|8[058]|4[013]|7[07]|6[046]|2[1-358]|1[0-2457])|6(?:01|20|55|68|1[018]|8[068])))',
+    '320' => '(?:8(?:5(?:5[015]|3[0-38]|8[058]|4[013]|7[07]|0[1-8]|6[046]|2[1-358]|1[0-2457])|6(?:01|20|55|68|1[018]|8[068])))',
     '321' => '(?:(?:3(?:29[2-8]|39[2358]|49[378]|59[578])|0(?:29[2358]|19[458]|59[235]|692)|2(?:59[23568]|49[23]|792)|4(?:39[23568]|29[235])|1(?:29[238]|49[23])|85(?:[58]5|0[25])))',
     '322' => '(?:(?:8(?:5(?:11|0[1-3]|8[58]|5[05])|6(?:66|88|0[13]))|0(?:393|692)))',
     '323' => '(?:(?:8(?:5(?:11|58|67|8[56])|6(?:[01]1|78|86)|75[56])|019[24]|1192))',
@@ -303,7 +303,7 @@ our %ZIP_TABLE = (
     '327' => '(?:(?:8(?:5(?:11|33|55|0[13])|6(?:78|0[13]))|0(?:59[25]|192|398)))',
     '328' => '(?:(?:8(?:5(?:33|0[1-4]|5[058]|8[5-8])|6(?:86|6[68]))|0192))',
     '329' => '(?:(?:0(?:49[238]|59[568]|69[26]|195)|1(?:19[3468]|39[235]|292|493)|2(?:79[23]|99[23]|[12]92)|4(?:49[238]|392)|3292))',
-    '330' => '(?:(?:9(?:5(?:90|5[013589]|4[03-58]|8[0-36-8]|6[4-6]|3[156]|2[05]|7[57]|1[12]|0[1-37-9])|7(?:9[1-367]|3[19]|2[07]|1[0357])|6(?:[69]6|11|30|88|0[18]|2[126])|3(?:30|77|0[13]|1[01])|1(?:09|1[01])|0(?:11|45))|8(?:5(?:4[78]|5[0-37]|0[13568]|6[24-7]|3[238]|1[0189]|2[29]|7[129]|8[0159])|6(?:34|47|69|71|86|0[13])|7(?:08|10|77))))',
+    '330' => '(?:(?:9(?:5(?:90|5[013589]|4[03-58]|8[0-36-8]|6[4-6]|3[156]|2[05]|7[57]|1[12]|0[1-37-9])|6(?:[69]6|30|88|1[19]|0[18]|2[126])|7(?:9[1-367]|3[19]|2[07]|1[0357])|3(?:30|77|0[13]|1[01])|1(?:09|1[01])|0(?:11|45))|8(?:5(?:4[78]|5[0-37]|0[13568]|6[24-7]|3[238]|1[0189]|2[29]|7[129]|8[0159])|6(?:34|47|69|71|86|0[13])|7(?:08|10|77))))',
     '331' => '(?:(?:8(?:5(?:[24]0|01|77|1[13]|5[02]|6[07]|3[237]|8[06-8])|6(?:25|33|58|8[6-8])|701)|9(?:5(?:[1-35]0|77)|624)))',
     '332' => '(?:8(?:5(?:21|48|77|85|0[1-3]|5[568]|1[12])|6(?:[68]6|01|54)))',
     '333' => '(?:86[01]1)',
@@ -343,7 +343,7 @@ our %ZIP_TABLE = (
     '367' => '(?:(?:0(?:29[26-8]|19[248]|393)|8(?:501|686)))',
     '368' => '(?:(?:8(?:6(?:66|8[06])|50[125])|0(?:19[235]|292)))',
     '369' => '(?:(?:1(?:29[2358]|89[2-5]|19[235]|59[236]|[34]92|998)|0(?:29[2357]|19[258]|39[235])))',
-    '370' => '(?:(?:8(?:5(?:[01]1|[68]5|22|43|3[17]|5[05])|6(?:[01]1|22|86|6[68]))|1(?:39[2-6]|19[2356]|29[23]|592)|0(?:59[568]|49[25]|193|692|795)|2(?:39[23568]|49[58]|[12]92)|3(?:59[2-4]|[146]92|39[23])))',
+    '370' => '(?:(?:8(?:5(?:[6-8]5|[01]1|22|43|3[17]|5[05])|6(?:[01]1|22|86|6[68]))|1(?:39[2-6]|19[2356]|29[23]|592)|0(?:59[568]|49[25]|193|692|795)|2(?:39[23568]|49[58]|[12]92)|3(?:59[2-4]|[146]92|39[23])))',
     '371' => '(?:(?:8(?:5(?:[58][05-7]|0[1-578]|1[0-7]|2[0-2578]|4[38]|3[01359]|7[023]|6[017])|6(?:[36]6|01|40|77|1[167]|2[05]|8[68]))|0(?:29[2-4]|192)))',
     '372' => '(?:8(?:5(?:10|58|67|8[058]|0[128])|686))',
     '373' => '(?:8(?:5(?:21|78|1[0-35]|0[1589]|8[58]|5[0157]|3[01]|6[017])|6(?:01|22|[68][068]|1[01])|718))',
@@ -363,7 +363,7 @@ our %ZIP_TABLE = (
     '387' => '(?:8(?:5(?:[26]1|[58]5|0[1-3]|1[12])|60[13]))',
     '388' => '(?:85(?:11|22|55))',
     '389' => '(?:(?:0(?:6(?:8[128]|9[235-8])|19[2-8]|29[23568]|89[2378]|59[238])|1(?:19[256]|293|392)|2(?:[1357]92|29[28])))',
-    '390' => '(?:(?:8(?:5(?:85|0[1-35-8]|2[0358]|4[013]|1[0158]|3[01359]|[56][05])|6(?:48|86|2[013]|3[09]|1[01]|0[1-35])|7(?:65|0[2-47]|1[0-24]))|1(?:1(?:9[378]|8[1-35-9])|29[358]|39[2-4]|[457]92)))',
+    '390' => '(?:(?:8(?:5(?:85|0[1-35-8]|2[0358]|4[013]|1[0158]|3[01359]|[56][05])|6(?:48|86|2[013]|1[01]|3[059]|0[1-35])|7(?:65|0[2-47]|1[0-24]))|1(?:1(?:9[378]|8[1-35-9])|29[358]|39[2-4]|[457]92)))',
     '391' => '(?:(?:85(?:31|40|0[13]|5[058]|6[0167]|1[0-2]|8[08]|2[125])|0(?:29[2-7]|39[2-6]|192)))',
     '392' => '(?:8(?:5(?:[58]5|20|7[78]|0[25]|4[089]|1[01])|6(?:86|2[78]|0[19]|1[01])))',
     '393' => '(?:8(?:5(?:[58]5|11|0[1-3])|601))',
@@ -469,7 +469,7 @@ our %ZIP_TABLE = (
     '496' => '(?:8(?:5(?:75|3[1-57]|0[138]|5[58])|6(?:01|48|86|3[39])|720))',
     '497' => '(?:8(?:5(?:[04][158]|3[138]|2[27]|1[0-2])|60[12]))',
     '498' => '(?:850[1-35])',
-    '500' => '(?:8(?:6(?:[14][0568]|5[057]|7[0-26-8]|2[0-25]|0[1-357]|8[0-25-79]|3[05-9]|6[06-8])|5(?:88|6[0-25-7]|0[1-578]|1[0358]|4[0145]|2[1-5]|3[035]|7[017]|5[024-8])|7(?:65|4[0-38]|2[1-357-9]|1[015-8]|3[0-479]|5[0-5]|0[1-378])))',
+    '500' => '(?:8(?:6(?:[14][0568]|5[057]|7[0-26-8]|2[0-25]|0[1-357]|8[0-25-79]|3[05-9]|6[06-8])|5(?:88|6[0-25-7]|0[1-578]|1[0358]|4[0145]|2[1-5]|3[035]|7[017]|5[024-8])|7(?:4[0-38]|2[1-357-9]|1[015-8]|3[0-479]|5[0-5]|0[1-378]|6[56])))',
     '501' => '(?:(?:0(?:69[2-8]|49[25-8]|29[346]|59[26]|79[78]|[13]92)|3(?:99[2-48]|29[356]|39[235]|89[2-4]|792)|6(?:1(?:9[2-8]|8[01])|29[235])|1(?:19[2-68]|39[23]|592)|4(?:29[278]|19[23]|59[25])|2(?:[1258]92|69[578])|5(?:[146]92|393)))',
     '502' => '(?:85(?:[12]1|58|67|85|0[13]))',
     '503' => '(?:(?:8(?:5(?:2[0-3]|[01][1-9]|5[02-4679]|7[01]|6[0-24-9])|60[134])|2(?:39[2-7]|49[2-5]|19[23])|0(?:19[28]|29[25]|[46]95|392)|1(?:39[2-6]|59[235]|696)))',
@@ -650,7 +650,7 @@ our %ZIP_TABLE = (
     '684' => '(?:8(?:5(?:[01]1|[58]5)|6(?:01|86)))',
     '685' => '(?:8(?:5(?:[58]5|12)|6(?:01|66)))',
     '689' => '(?:(?:2(?:29[2358]|39[235])|(?:[45]2|3[45])92|059[25]|119[23]))',
-    '690' => '(?:(?:8(?:5(?:40|77|1\d|0[1-9]|5[0-68]|6[07]|2[0-35-8]|3[0-3569]|8[08])|6(?:[01]1|7[07]|6[068]|8[68])|794)|039[36]|219[28]|1492))',
+    '690' => '(?:(?:8(?:5(?:40|77|1\d|0[1-9]|6[07]|5[0-689]|2[0-35-8]|3[0-3569]|8[08])|6(?:[01]1|7[07]|6[068]|8[68])|794)|039[36]|219[28]|1492))',
     '691' => '(?:860[12])',
     '692' => '(?:8(?:5(?:[15]0|06)|6(?:86|0[16])))',
     '693' => '(?:8(?:5(?:01|23|66|3[013]|5[05]|8[57]|1[01])|6(?:01|14|8[69])))',
@@ -896,7 +896,7 @@ our %ZIP_TABLE = (
     '937' => '(?:8(?:5(?:[58]5|03|11|6[67])|6(?:01|60|78)))',
     '938' => '(?:(?:8(?:6(?:1[0-3]|0[12])|5(?:[58]5|0[25]))|029[23]))',
     '939' => '(?:(?:8(?:5(?:21|67|0[127]|[58][058]|1[0157]|7[12])|6(?:01|50|3[06]|4[02]|1[01]))|1(?:39[2-8]|89[23578]|59[2356]|69[2-48]|19[23]|99[78]|492)|0(?:29[2-6]|79[2358]|39[258]|[15]92|693)|2(?:29[23578]|39[238]|69[24]|192|595|798)|3593))',
-    '940' => '(?:(?:8(?:5(?:67|7[027]|3[02]|2[12]|0[18]|5[0458]|1[01]|8[03568])|6(?:41|60|86|3[013]|5[0134]|0[235]|[12][0-2]))|2(?:1(?:8[1-468]|9[258])|0(?:93|8[1-358])|59[25]|[34]92)|029[2-8]|119[3-68]))',
+    '940' => '(?:(?:8(?:5(?:67|7[027]|3[02]|2[12]|0[18]|5[0458]|1[01]|8[03568])|6(?:41|60|86|3[013]|0[235]|5[013-5]|[12][0-2]))|2(?:1(?:8[1-468]|9[258])|0(?:93|8[1-358])|59[25]|[34]92)|029[2-8]|119[3-68]))',
     '941' => '(?:8(?:6(?:[01]1|86)|50[12]))',
     '942' => '(?:(?:8(?:5(?:63|0[1258])|6(?:[01]1|66))|0(?:19[2-6]|39[238]|492)|1492))',
     '943' => '(?:(?:8(?:5(?:61|1[025]|5[1258]|4[045]|3[0134]|2[0-25]|8[58]|0[1-35])|6(?:1[06]|0[147]))|0(?:19[23]|595|692)))',
